:mod:`mozanalysis.segments.desktop`
-----------------------------------

See the source for the included segments. Sphinx seems to be uncooperative displaying source code that does not define functions or classes - so view the latest source `on github <https://github.com/mozilla/mozanalysis/tree/master/src/mozanalysis/segments/desktop.py>`_.
